from setuptools import setup, find_packages
import os


VERSION = '0.0.0'
DESCRIPTION = 'Zeroday | Comming Soon...'

setup(
    name="zeroday",
    version=VERSION,
    author="S41R4J",
    author_email="<v1b7rc8eb@relay.firefox.com>",
    description=DESCRIPTION,
    packages=find_packages(),
)